/*
 * $Id: ClasspathAgentMBean.java,v 1.5 2012/03/22 18:11:52 oboehm Exp $
 *
 * Copyright (c) 2012 by Oliver Boehm
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express orimplied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * (c)reated 02.03.2012 by oliver (ob@oasd.de)
 */

package patterntesting.agent;

import java.io.Serializable;

/**
 * This is the MBean for the {@link ClasspathAgent} to be able to register
 * this class for the jconsole.
 * 
 * @author oliver
 * @since 1.2.10-YEARS (02.03.2012)
 */
public interface ClasspathAgentMBean extends Serializable{
    
    /**
     * Checks if is active. This is true if this class here was started as
     * Java agent.
     *
     * @return true, if started as Java agent
     */
    boolean isActive();

    /**
     * Get the arguments from the call as agent
     *
     * @return the args
     */
    String getArgs();

    /**
     * Returns the classes which were loaded by the classloader.
     *
     * @return the classes as string array
     */
    Class<?>[] getLoadedClasses();
    
    /**
     * Returns the classes which were loaded by the classloader.
     * The loaded packages are returned as string array so that it can
     * be displayed by the 'jconsole'.
     *
     * @return the classnames as string array
     */
    String[] getLoadedClassnames();
    
    /**
     * Gets the loaded classes.
     *
     * @param classloader the classloader
     * @return the loaded classes
     */
    Class<?>[] getLoadedClasses(final ClassLoader classloader);

}

